==> jc-1.4.0.tar.gz: javax/print/attribute/standard/PrinterResolution.h <==
// public final class javax.print.attribute.standard.PrinterResolution

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8bf9b1ed87f70b13 javax_print_attribute_ResolutionSyntax
// @dep_class 52d814bb22d9f990 javax_print_attribute_standard_PrinterResolution

// header file dependencies
// @dep_header javax_print_attribute_ResolutionSyntax

#include "javax/print/attribute/ResolutionSyntax.h"

#ifndef _JC_javax_print_attribute_standard_PrinterResolution_H_
#define _JC_javax_print_attribute_standard_PrinterResolution_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_PrinterResolution$sub_refs	_jc_javax_print_attribute_standard_PrinterResolution$sub_refs;
typedef struct _jc_javax_print_attribute_standard_PrinterResolution$sub_nonrefs	_jc_javax_print_attribute_standard_PrinterResolution$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterResolution$refs	_jc_javax_print_attribute_standard_PrinterResolution$refs;
typedef struct _jc_javax_print_attribute_standard_PrinterResolution$nonrefs	_jc_javax_print_attribute_standard_PrinterResolution$nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterResolution$object	_jc_javax_print_attribute_standard_PrinterResolution$object;

typedef struct _jc_javax_print_attribute_standard_PrinterResolution$fields_struct	_jc_javax_print_attribute_standard_PrinterResolution$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_PrinterResolution$vmethods	_jc_javax_print_attribute_standard_PrinterResolution$vmethods;
typedef const struct _jc_javax_print_attribute_standard_PrinterResolution$vtable	_jc_javax_print_attribute_standard_PrinterResolution$vtable;
typedef const struct _jc_javax_print_attribute_standard_PrinterResolution$vtype	_jc_javax_print_attribute_standard_PrinterResolution$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_PrinterResolution$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24PrinterResolution;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_PrinterResolution$fields_struct _jc_javax_print_attribute_standard_PrinterResolution$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_PrinterResolution$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterResolution$object *, jint, jint, jint);

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterResolution$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterResolution$object *);
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_PrinterResolution$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterResolution$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_PrinterResolution$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_PrinterResolution$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterResolution$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_javax_print_attribute_standard_PrinterResolution$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterResolution$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterResolution$object *);
};

// Vtable
struct _jc_javax_print_attribute_standard_PrinterResolution$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_ResolutionSyntax$vmethods	javax_print_attribute_ResolutionSyntax;
	_jc_javax_print_attribute_standard_PrinterResolution$vmethods	javax_print_attribute_standard_PrinterResolution;
};

// Vtype
struct _jc_javax_print_attribute_standard_PrinterResolution$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_PrinterResolution$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterResolution$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterResolution$refs {
    _jc_javax_print_attribute_standard_PrinterResolution$sub_refs	javax_print_attribute_standard_PrinterResolution;
    _jc_javax_print_attribute_ResolutionSyntax$sub_refs	javax_print_attribute_ResolutionSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterResolution$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterResolution$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_ResolutionSyntax$sub_nonrefs	javax_print_attribute_ResolutionSyntax;
    _jc_javax_print_attribute_standard_PrinterResolution$sub_nonrefs	javax_print_attribute_standard_PrinterResolution;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_PrinterResolution$object {
	_jc_javax_print_attribute_standard_PrinterResolution$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_PrinterResolution$vtype	*vtype;
	_jc_javax_print_attribute_standard_PrinterResolution$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_PrinterResolution$vtype _jc_javax_print_attribute_standard_PrinterResolution$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_PrinterResolution, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_PrinterResolution$class_object;

#endif	/* _JC_javax_print_attribute_standard_PrinterResolution_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/standard/PrinterResolution.h <==
// public final class javax.print.attribute.standard.PrinterResolution

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8bf9b1ed87f70b13 javax_print_attribute_ResolutionSyntax
// @dep_class 52d814bb22d9f990 javax_print_attribute_standard_PrinterResolution

// header file dependencies
// @dep_header javax_print_attribute_ResolutionSyntax

#include "javax/print/attribute/ResolutionSyntax.h"

#ifndef _JC_javax_print_attribute_standard_PrinterResolution_H_
#define _JC_javax_print_attribute_standard_PrinterResolution_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_attribute_standard_PrinterResolution$sub_refs	_jc_javax_print_attribute_standard_PrinterResolution$sub_refs;
typedef struct _jc_javax_print_attribute_standard_PrinterResolution$sub_nonrefs	_jc_javax_print_attribute_standard_PrinterResolution$sub_nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterResolution$refs	_jc_javax_print_attribute_standard_PrinterResolution$refs;
typedef struct _jc_javax_print_attribute_standard_PrinterResolution$nonrefs	_jc_javax_print_attribute_standard_PrinterResolution$nonrefs;
typedef struct _jc_javax_print_attribute_standard_PrinterResolution$object	_jc_javax_print_attribute_standard_PrinterResolution$object;

typedef struct _jc_javax_print_attribute_standard_PrinterResolution$fields_struct	_jc_javax_print_attribute_standard_PrinterResolution$fields_struct;
typedef const struct _jc_javax_print_attribute_standard_PrinterResolution$vmethods	_jc_javax_print_attribute_standard_PrinterResolution$vmethods;
typedef const struct _jc_javax_print_attribute_standard_PrinterResolution$vtable	_jc_javax_print_attribute_standard_PrinterResolution$vtable;
typedef const struct _jc_javax_print_attribute_standard_PrinterResolution$vtype	_jc_javax_print_attribute_standard_PrinterResolution$vtype;

// Class fields structure
struct _jc_javax_print_attribute_standard_PrinterResolution$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24print__24attribute__24standard__24PrinterResolution;
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_standard_PrinterResolution$fields_struct _jc_javax_print_attribute_standard_PrinterResolution$class_fields;

// Constructors
extern void _jc_javax_print_attribute_standard_PrinterResolution$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterResolution$object *, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterResolution$method$getCategory$1a83ac042894bcc8(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterResolution$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_print_attribute_standard_PrinterResolution$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterResolution$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_standard_PrinterResolution$method_info$getCategory$1a83ac042894bcc8;
extern _jc_method _jc_javax_print_attribute_standard_PrinterResolution$method_info$getName$bec186f2ce7e1882;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_javax_print_attribute_standard_PrinterResolution$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_attribute_standard_PrinterResolution$vmethods {
	struct _jc_java_lang_Class$object	*(*getCategory$1a83ac042894bcc8)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterResolution$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_javax_print_attribute_standard_PrinterResolution$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_standard_PrinterResolution$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_ResolutionSyntax$vmethods	javax_print_attribute_ResolutionSyntax;
	_jc_javax_print_attribute_standard_PrinterResolution$vmethods	javax_print_attribute_standard_PrinterResolution;
};

// Vtype
struct _jc_javax_print_attribute_standard_PrinterResolution$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_standard_PrinterResolution$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterResolution$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterResolution$refs {
    _jc_javax_print_attribute_standard_PrinterResolution$sub_refs	javax_print_attribute_standard_PrinterResolution;
    _jc_javax_print_attribute_ResolutionSyntax$sub_refs	javax_print_attribute_ResolutionSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_standard_PrinterResolution$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_standard_PrinterResolution$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_ResolutionSyntax$sub_nonrefs	javax_print_attribute_ResolutionSyntax;
    _jc_javax_print_attribute_standard_PrinterResolution$sub_nonrefs	javax_print_attribute_standard_PrinterResolution;
};

// Object instance structure
struct _jc_javax_print_attribute_standard_PrinterResolution$object {
	_jc_javax_print_attribute_standard_PrinterResolution$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_standard_PrinterResolution$vtype	*vtype;
	_jc_javax_print_attribute_standard_PrinterResolution$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_standard_PrinterResolution$vtype _jc_javax_print_attribute_standard_PrinterResolution$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_standard_PrinterResolution, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_standard_PrinterResolution$class_object;

#endif	/* _JC_javax_print_attribute_standard_PrinterResolution_H_ */
